@@ -42,22 +42,42 @@
 #endif
 
 /* Define the version number so folks can check against it */
+/* Note, maintainers are expected to update this to match configure.ac for each release */
 #define TC_VERSION_MAJOR  2
-#define TC_VERSION_MINOR  12
-#define TC_VERSION_PATCH  ""
-#define TC_VERSION_STRING "gperftools 2.12"
+#define TC_VERSION_MINOR  17
+#define TC_VERSION_PATCH  ".2"
+#define TC_VERSION_STRING "gperftools 2.17.2"
+
+#if __GLIBC__ * 1000 + __GLIBC_MINOR__ >= 2033
+/* glibc 2.33 has mallinfo2 */
+#define GPERFTOOLS_HAS_MALLINFO2 1
+#define GPERFTOOLS_HAS_MALLINFO 1
+#elif defined(__GLIBC__)
+/* earlier glibc-s have mallinfo */
+#define GPERFTOOLS_HAS_MALLINFO 1
+#elif defined(__sun__)
+/* Some version of Solaris actually introduced mallinfo. It is still
+ * there with current opensolaris. */
+#define GPERFTOOLS_HAS_MALLINFO 1
+#elif defined(__ANDROID__) && __ANDROID_API__ >= 34
+/* ndk 24 has mallinfo2 */
+#define GPERFTOOLS_HAS_MALLINFO2 1
+#define GPERFTOOLS_HAS_MALLINFO 1
+#elif defined(__ANDROID__)
+#define GPERFTOOLS_HAS_MALLINFO 1
+#endif
+// musl doesn't do mallinfo
+// uclibc does in a subset of configs, but given mallinfo is rare API we keep it simple.
 
 /* For struct mallinfo, if it's defined. */
-#if 1
+#if GPERFTOOLS_HAS_MALLINFO || GPERFTOOLS_HAS_MALLINFO2
 # include <malloc.h>
 #endif
 
 #ifndef PERFTOOLS_NOTHROW
 
-#if __cplusplus >= 201103L
+#ifdef __cplusplus
 #define PERFTOOLS_NOTHROW noexcept
-#elif defined(__cplusplus)
-#define PERFTOOLS_NOTHROW throw()
 #else
 # ifdef __GNUC__
 #  define PERFTOOLS_NOTHROW __attribute__((__nothrow__))
@@ -81,7 +101,7 @@ extern "C" {
 #endif
   /*
    * Returns a human-readable version string.  If major, minor,
-   * and/or patch are not NULL, they are set to the major version,
+   * and/or patch are not nullptr, they are set to the major version,
    * minor version, and patch-code (a string, usually "").
    */
   PERFTOOLS_DLL_DECL const char* tc_version(int* major, int* minor,
@@ -90,7 +110,11 @@ extern "C" {
   PERFTOOLS_DLL_DECL void* tc_malloc(size_t size) PERFTOOLS_NOTHROW;
   PERFTOOLS_DLL_DECL void* tc_malloc_skip_new_handler(size_t size) PERFTOOLS_NOTHROW;
   PERFTOOLS_DLL_DECL void tc_free(void* ptr) PERFTOOLS_NOTHROW;
+
+  // Versions of C23 sized free stuff
   PERFTOOLS_DLL_DECL void tc_free_sized(void *ptr, size_t size) PERFTOOLS_NOTHROW;
+  PERFTOOLS_DLL_DECL void tc_free_aligned_sized(void* ptr, size_t align, size_t size) PERFTOOLS_NOTHROW;
+
   PERFTOOLS_DLL_DECL void* tc_realloc(void* ptr, size_t size) PERFTOOLS_NOTHROW;
   PERFTOOLS_DLL_DECL void* tc_calloc(size_t nmemb, size_t size) PERFTOOLS_NOTHROW;
   PERFTOOLS_DLL_DECL void tc_cfree(void* ptr) PERFTOOLS_NOTHROW;
@@ -104,9 +128,14 @@ extern "C" {
 
   PERFTOOLS_DLL_DECL void tc_malloc_stats(void) PERFTOOLS_NOTHROW;
   PERFTOOLS_DLL_DECL int tc_mallopt(int cmd, int value) PERFTOOLS_NOTHROW;
-#if 1
+
+
+#if GPERFTOOLS_HAS_MALLINFO
   PERFTOOLS_DLL_DECL struct mallinfo tc_mallinfo(void) PERFTOOLS_NOTHROW;
 #endif
+#if GPERFTOOLS_HAS_MALLINFO2
+  PERFTOOLS_DLL_DECL struct mallinfo2 tc_mallinfo2(void) PERFTOOLS_NOTHROW;
+#endif
 
   /*
    * This is an alias for MallocExtension::instance()->GetAllocatedSize().
@@ -134,7 +163,9 @@ extern "C" {
   PERFTOOLS_DLL_DECL void tc_deletearray_nothrow(void* p,
                                                  const std::nothrow_t&) PERFTOOLS_NOTHROW;
 
-#if 1 && __cplusplus >= 201703L
+#if defined(__cpp_aligned_new) || \
+    (defined(__cplusplus) && __cplusplus >= 201703L) || \
+    (defined(_MSVC_LANG) && _MSVC_LANG >= 201703L)
   PERFTOOLS_DLL_DECL void* tc_new_aligned(size_t size, std::align_val_t al);
   PERFTOOLS_DLL_DECL void* tc_new_aligned_nothrow(size_t size, std::align_val_t al,
                                           const std::nothrow_t&) PERFTOOLS_NOTHROW;
@@ -150,6 +181,7 @@ extern "C" {
   PERFTOOLS_DLL_DECL void tc_deletearray_aligned_nothrow(void* p, std::align_val_t al,
                                                  const std::nothrow_t&) PERFTOOLS_NOTHROW;
 #endif
+
 }
 #endif
 
